@@ -363,20 +363,10 @@ class RESTAPI :
                 "damagedealttoturrets" : int(participant['damageDealtToTurrets']),
                 "damageselfmitigated" : int(participant['damageSelfMitigated']),
                 "deaths" : int(participant['deaths']),
-                "doublekills" : int(participant['doubleKills']),
-                "dragonkills" : int(participant['dragonKills']),
-                "firstbloodassist" : int(participant['firstBloodAssist']),
-                "firstbloodkill" : int(participant['firstBloodKill']),
-                "firsttowerassisted" : int(participant['firstTowerAssist']),
-                "firsttowerkill" : int(participant['firstTowerKill']),
-                "gameendedinearlysurrender" : participant['gameEndedInEarlySurrender'],
                 "gameendedinsurrender" : participant['gameEndedInSurrender'],
                 "goldearned" : int(participant['goldEarned']),
                 "goldspent" : int(participant['goldSpent']),
                 "individualposition" : "{individualPosition}".format(individualPosition=participant['individualPosition']),
-                "inhibitorkills" : int(participant['inhibitorKills']),
-                "inhibitortakedowns" : int(participant['inhibitorTakedowns']),
-                "inhibitorslost" : int(participant['inhibitorsLost']),
                 "item0" : int(participant['item0']),
                 "item1" : int(participant['item1']),
                 "item2" : int(participant['item2']),
@@ -386,19 +376,13 @@ class RESTAPI :
                 "item6" : int(participant['item6']),
                 "kills" : int(participant['kills']),
                 "lane" : "{lane}".format(lane=participant['lane']),
-                "largestcriticalstrike" : int(participant['largestCriticalStrike']),
                 "magicdamagedealt" : int(participant['magicDamageDealt']),
                 "magicdamagedealttochampions" : int(participant['magicDamageDealtToChampions']),
-                "magicdamagetaken" : int(participant['magicDamageTaken']),
-                "neutralminionskilled" : int(participant['neutralMinionsKilled']),
                 "participantid" : int(participant['participantId']),
-                "pentakills" : int(participant['pentaKills']),
                 "physicaldamagedealt" : int(participant['physicalDamageDealt']),
                 "physicaldamagedealttochampions" : int(participant['physicalDamageDealtToChampions']),
-                "physicaldamagetaken" : int(participant['physicalDamageTaken']),
                 "profileiconid" : int(participant['profileIcon']),
                 "puuid" : puuid,
-                "quadrakills" : int(participant['quadraKills']),
                 "riotidname" : "{riotIdName}".format(riotIdName=participant['riotIdName']),
                 "riotidtagline" : "{riotIdTagline}".format(riotIdTagline=participant['riotIdTagline']),
                 "role" : "{role}".format(role=participant['role']),
@@ -417,24 +401,12 @@ class RESTAPI :
                 "teamearlysurrendered" : participant['teamEarlySurrendered'],
                 "teamid" : int(participant['teamId']),
                 "teamposition" : "{teamPosition}".format(teamPosition=participant['teamPosition']),
-                "timeccingothers" : int(participant['timeCCingOthers']),
                 "totaldamagedealt" : int(participant['totalDamageDealt']),
                 "totaldamagedealttochampions" : int(participant['totalDamageDealtToChampions']),
-                "totaldamageshieldedonteammates" : int(participant['totalDamageShieldedOnTeammates']),
-                "totaldamagetaken" : int(participant['totalDamageTaken']),
                 "totalheal" : int(participant['totalHeal']),
-                "totalhealsonteammates" : int(participant['totalHealsOnTeammates']),
                 "totalminionskilled" : int(participant['totalMinionsKilled']),
-                "totaltimeccdealt" : int(participant['totalTimeCCDealt']),
-                "totaltimespentdead" : int(participant['totalTimeSpentDead']),
-                "totalunitshealed" : int(participant['totalUnitsHealed']),
-                "triplekills" : int(participant['tripleKills']),
                 "truedamagedealt" : int(participant['trueDamageDealt']),
                 "truedamagedealttochampions" : int(participant['trueDamageDealtToChampions']),
-                "truedamagetaken" : int(participant['trueDamageTaken']),
-                "turretkills" : int(participant['turretKills']),
-                "turrettakedowns" : int(participant['turretTakedowns']),
-                "turretslost" : int(participant['turretsLost']),
                 "win" : participant['win']
             }
         
